@@ -1,17 +1,17 @@
 ;(function(){
   var map = {
-  "commitId": "a29fbaef9716aeb964cab7fdbf9900190e316a58",
-  "branchName": "release-client-5.13.5",
-  "buildTime": "Mon, 16 Jan 2023 08:07:55 GMT",
-  "buildVersion": "5.1.277",
+  "commitId": "c36192f84629a03bf436e19198e10c0deb263443",
+  "branchName": "release-client-5.13.x",
+  "buildTime": "Mon, 27 Feb 2023 01:50:51 GMT",
+  "buildVersion": "5.1.296",
   "css": [
-    "@zoom/client-calendar/static/css/vendors~app.07e6810a.css",
-    "@zoom/client-calendar/static/css/app.1ed23e5d.css"
+    "@zoom/client-calendar/static/css/default~app.175ea1dd.css",
+    "@zoom/client-calendar/static/css/vendors~app.f43a7829.css"
   ],
   "js": [
-    "@zoom/client-calendar/static/js/vendors~app.0316c293.js",
-    "@zoom/client-calendar/static/js/zoomUI~app.78a33c3b.js",
-    "@zoom/client-calendar/static/js/app.a9d45ad8.js"
+    "@zoom/client-calendar/static/js/default~app.52058614.js",
+    "@zoom/client-calendar/static/js/vendors~app.700ab55d.js",
+    "@zoom/client-calendar/static/js/app.7b88a06c.js"
   ]
 };
   var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
